"""
:synopsis: Loss functions to use with NPU API for training
.. moduleauthor:: Naval Bhandari <naval@neuro-ai.co.uk>
"""

CrossEntropyLoss = "CrossEntropyLoss"  #:
SparseCrossEntropyLoss = "SparseCrossEntropyLoss"  #:
MSELoss = "MSELoss"  #:
CTCLoss = "CTCLoss"  #:
L1Loss = "L1Loss"  #:
NLLLoss = "NLLLoss"  #:
