"""
:synopsis: Global models available
.. moduleauthor:: Naval Bhandari <naval@neuro-ai.co.uk>
"""

from ..core import Model

resnet18 = Model("resnet18")
""":resnet18: Resnet 18 model. Access pretrained version `resnet18(pretrained=True)` """

vgg16 = Model("vgg16")
""":vgg16: VGG16 model. Access pretrained version `vgg16(pretrained=True)` """


